@@ -17,7 +17,6 @@
 #' @rdname Assay-class
 #'
 #' @seealso \code{\link[SeuratObject:Assay]{SeuratObject::Assay-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -36,7 +35,6 @@ NULL
 #' @rdname DimReduc-class
 #'
 #' @seealso \code{\link[SeuratObject:DimReduc]{SeuratObject::DimReduc-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -54,7 +52,6 @@ NULL
 #' @rdname Graph-class
 #'
 #' @seealso \code{\link[SeuratObject:Graph]{SeuratObject::Graph-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -72,7 +69,6 @@ NULL
 #' @rdname JackStrawData-class
 #'
 #' @seealso \code{\link[SeuratObject:JackStrawData]{SeuratObject::JackStrawData-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -90,7 +86,6 @@ NULL
 #' @rdname Neighbor-class
 #'
 #' @seealso \code{\link[SeuratObject:Neighbor]{SeuratObject::Neighbor-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -109,7 +104,6 @@ NULL
 #' @rdname Seurat-class
 #'
 #' @seealso \code{\link[SeuratObject:Seurat]{SeuratObject::Seurat-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -127,7 +121,6 @@ NULL
 #' @rdname SeuratCommand-class
 #'
 #' @seealso \code{\link[SeuratObject:SeuratCommand]{SeuratObject::SeuratCommand-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -145,7 +138,6 @@ NULL
 #' @rdname SpatialImage-class
 #'
 #' @seealso \code{\link[SeuratObject:SpatialImage]{SeuratObject::SpatialImage-class}}
-#' @keywords internal
 #'
 NULL
 
@@ -153,6 +145,16 @@ NULL
 # Functions and Generics
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+#' @importFrom SeuratObject %||%
+#' @export
+#'
+SeuratObject::`%||%`
+
+#' @importFrom SeuratObject %iff%
+#' @export
+#'
+SeuratObject::`%iff%`
+
 #' @importFrom SeuratObject AddMetaData
 #' @export
 #'
